@@ -489,6 +489,9 @@ brasero_data_tree_model_get_value (GtkTreeModel *model,
 					       NULL,
 					       NULL,
 					       NULL);
+		if (!filename)
+			filename = brasero_utils_validate_utf8 (BRASERO_FILE_NODE_NAME (node));
+
 		if (filename)
 			g_value_set_string (value, filename);
 		else	/* Glib section on g_convert advise to use a string like
@@ -586,8 +589,6 @@ brasero_data_tree_model_get_value (GtkTreeModel *model,
 			nb_items = brasero_file_node_get_n_children (node);
 			if (!nb_items)
 				g_value_set_string (value, _("Empty"));
-			else if (nb_items == 1)
-				g_value_set_string (value, _("1 item"));
 			else {
 				gchar *text;
 
@@ -599,7 +600,7 @@ brasero_data_tree_model_get_value (GtkTreeModel *model,
 		else {
 			gchar *text;
 
-			text = brasero_utils_get_size_string (BRASERO_FILE_NODE_SECTORS (node) * 2048, TRUE, TRUE);
+			text = g_format_size_for_display (BRASERO_FILE_NODE_SECTORS (node) * 2048);
 			g_value_set_string (value, text);
 			g_free (text);
 		}
