@@ -32,16 +32,7 @@
 #include <glib-object.h>
 #include <glib/gi18n-lib.h>
 
-#include <gtk/gtktoolbar.h>
-#include <gtk/gtkuimanager.h>
-#include <gtk/gtkcontainer.h>
-#include <gtk/gtknotebook.h>
-#include <gtk/gtktreednd.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtkframe.h>
-#include <gtk/gtkeventbox.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkmisc.h>
+#include <gtk/gtk.h>
 
 #include "brasero-marshal.h"
 #include "brasero-disc.h"
@@ -142,23 +133,6 @@ brasero_disc_base_init (gpointer g_class)
 	initialized = TRUE;
 }
 
-BraseroDiscResult
-brasero_disc_can_add_uri (BraseroDisc *disc,
-			  const gchar *uri)
-{
-	BraseroDiscIface *iface;
-
-	g_return_val_if_fail (BRASERO_IS_DISC (disc), BRASERO_DISC_ERROR_UNKNOWN);
-	g_return_val_if_fail (uri != NULL, BRASERO_DISC_ERROR_UNKNOWN);
-	
-	iface = BRASERO_DISC_GET_IFACE (disc);
-	if (iface->can_add_uri)
-		return (* iface->can_add_uri) (disc, uri);
-
-	/* default to OK */
-	return BRASERO_DISC_OK;
-}
-
 BraseroDiscResult
 brasero_disc_add_uri (BraseroDisc *disc,
 		      const gchar *uri)
@@ -212,7 +186,9 @@ brasero_disc_reset (BraseroDisc *disc)
 }
 
 BraseroDiscResult
-brasero_disc_get_status (BraseroDisc *disc)
+brasero_disc_get_status (BraseroDisc *disc,
+			 gint *remaining,
+			 gchar **current_task)
 {
 	BraseroDiscIface *iface;
 
@@ -220,7 +196,9 @@ brasero_disc_get_status (BraseroDisc *disc)
 	
 	iface = BRASERO_DISC_GET_IFACE (disc);
 	if (iface->get_status)
-		return (* iface->get_status) (disc);
+		return (* iface->get_status) (disc,
+					      remaining,
+					      current_task);
 
 	return BRASERO_DISC_ERROR_UNKNOWN;
 }
@@ -337,22 +315,6 @@ brasero_disc_add_ui (BraseroDisc *disc, GtkUIManager *manager, GtkWidget *messag
 	return 0;
 }
 
-void
-brasero_disc_set_current_drive (BraseroDisc *disc,
-				BraseroDrive *drive)
-{
-	BraseroDiscIface *iface;
-
-	if (!disc)
-		return;
-
-	g_return_if_fail (BRASERO_IS_DISC (disc));
-
-	iface = BRASERO_DISC_GET_IFACE (disc);
-	if (iface->set_drive)
-		(* iface->set_drive) (disc, drive);
-}
-
 void
 brasero_disc_selection_changed (BraseroDisc *disc)
 {
@@ -601,9 +563,30 @@ brasero_utils_disc_realized_cb (GtkWidget *event_box,
 			  event_box);
 }
 
+static gboolean
+brasero_disc_draw_focus_around_help_text (GtkWidget *label,
+					  GdkEventExpose *event,
+					  gpointer NULL_data)
+{
+	if (!gtk_widget_is_focus (label))
+		return FALSE;
+
+	gtk_paint_focus (label->style,
+			 label->window,
+			 GTK_STATE_NORMAL,
+			 &event->area,
+			 label,
+			 NULL,
+			 label->style->xthickness, label->style->ythickness,
+			 label->allocation.width - label->style->xthickness * 2,
+			 label->allocation.height - label->style->ythickness * 2);
+	return FALSE;
+}
+
 GtkWidget *
 brasero_disc_get_use_info_notebook (void)
 {
+	GList	  *chain;
 	GtkWidget *frame;
 	GtkWidget *notebook;
 	GtkWidget *event_box;
@@ -667,11 +650,10 @@ brasero_disc_get_use_info_notebook (void)
 	 * You simply have to translate messages in the best form
          * for a list of actions. */
 	message_add_header = g_strconcat ("<big>", _("To add files to this project you can:"), "\n</big>", NULL);
-	message_add = g_strconcat ("\t* ", _("click the \"Add\" button to show the selection pane"), "\n",
-				   "\t* ", _("select files in selection pane and click the \"Add\" button"), "\n",
+	message_add = g_strconcat ("\t* ", _("click the \"Add\" button to show a selection dialog"), "\n",
+				   "\t* ", _("select files in the selection pane and click the \"Add\" button"), "\n",
 				   "\t* ", _("drag files in this area from the selection pane or from the file manager"), "\n",
 				   "\t* ", _("double click on files in the selection pane"), "\n",
-
 				   "\t* ", _("copy files (from file manager for example) and paste in this area"), "\n",
 				   NULL);
 
@@ -690,6 +672,7 @@ brasero_disc_get_use_info_notebook (void)
 					 "</span>", NULL);
 	first_use = gtk_label_new (first_use_message);
 	gtk_misc_set_alignment (GTK_MISC (first_use), 0.50, 0.30);
+	gtk_label_set_selectable (GTK_LABEL (first_use), TRUE);
 	gtk_label_set_ellipsize (GTK_LABEL (first_use), PANGO_ELLIPSIZE_END);
 	g_free (first_use_message);
 
@@ -698,6 +681,25 @@ brasero_disc_get_use_info_notebook (void)
 	gtk_label_set_use_markup (GTK_LABEL (first_use), TRUE);
 	gtk_container_add (GTK_CONTAINER (event_box), first_use);
 
+	/* This is meant for accessibility so that screen readers can read it */
+	g_object_set (first_use,
+		      "can-focus", TRUE,
+		      NULL);
+
+	g_signal_connect_after (first_use,
+				"expose-event",
+				G_CALLBACK (brasero_disc_draw_focus_around_help_text),
+				NULL);
+	/* We don't want to have the whole text selected */
+	g_object_set (gtk_widget_get_settings (first_use),
+		      "gtk-label-select-on-focus", FALSE,
+		      NULL);
+
+	chain = g_list_prepend (NULL, first_use);
+	gtk_container_set_focus_chain (GTK_CONTAINER (frame), chain);
+	g_list_free (chain);
+
+	/* This gets all events and forward them to treeview */
 	gtk_event_box_set_above_child (GTK_EVENT_BOX (event_box), TRUE);
 
 	g_free (message_add_header);
@@ -714,44 +716,3 @@ brasero_disc_get_use_info_notebook (void)
 	return notebook;
 }
 
-/************************************ ******************************************/
-static void
-brasero_track_clear_song (gpointer data)
-{
-	BraseroDiscSong *song;
-
-	song = data;
-
-	if (song->info)
-		brasero_song_info_free (song->info);
-
-	g_free (song->uri);
-	g_free (song);
-}
-
-void
-brasero_track_clear (BraseroDiscTrack *track)
-{
-	if (!track)
-		return;
-
-	if (track->type == BRASERO_DISC_TRACK_AUDIO) {
-		g_slist_foreach (track->contents.tracks, (GFunc) brasero_track_clear_song, NULL);
-		g_slist_free (track->contents.tracks);
-	}
-	else if (track->type == BRASERO_DISC_TRACK_DATA) {
-		g_slist_foreach (track->contents.data.grafts, (GFunc) brasero_graft_point_free, NULL);
-		g_slist_free (track->contents.data.grafts);
-		g_slist_foreach (track->contents.data.restored, (GFunc) g_free, NULL);
-		g_slist_free (track->contents.data.restored);
-		g_slist_foreach (track->contents.data.excluded, (GFunc) g_free, NULL);
-		g_slist_free (track->contents.data.excluded);
-	}
-}
-
-void
-brasero_track_free (BraseroDiscTrack *track)
-{
-	brasero_track_clear (track);
-	g_free (track);
-}
