@@ -159,7 +159,7 @@ brasero_drive_properties_set_tmpdir_info (BraseroDriveProperties *self,
 	vol_size = g_file_info_get_attribute_uint64 (info, G_FILE_ATTRIBUTE_FILESYSTEM_FREE);
 	g_object_unref (info);
 
-	string = brasero_utils_get_size_string (vol_size, TRUE, TRUE);
+	string = g_format_size_for_display (vol_size);
 	gtk_label_set_text (GTK_LABEL (priv->tmpdir_size), string);
 	g_free (string);
 }
@@ -427,15 +427,20 @@ brasero_drive_properties_format_disc_speed (BraseroMedia media,
 	gchar *text;
 
 	if (media & BRASERO_MEDIUM_DVD)
+		/* Translators %s.1f is the speed used to burn */
 		text = g_strdup_printf (_("%.1f x (DVD)"),
 					BRASERO_RATE_TO_SPEED_DVD (rate));
 	else if (media & BRASERO_MEDIUM_CD)
+		/* Translators %s.1f is the speed used to burn */
 		text = g_strdup_printf (_("%.1f x (CD)"),
 					BRASERO_RATE_TO_SPEED_CD (rate));
 	else if (media & BRASERO_MEDIUM_BD)
+		/* Translators %s.1f is the speed used to burn */
 		text = g_strdup_printf (_("%.1f x (BD)"),
 					BRASERO_RATE_TO_SPEED_BD (rate));
 	else
+		/* Translators %s.1f is the speed used to burn for every medium
+		 * type*/
 		text = g_strdup_printf (_("%.1f x (BD) %.1f x (DVD) %.1f x (CD)"),
 					BRASERO_RATE_TO_SPEED_BD (rate),
 					BRASERO_RATE_TO_SPEED_DVD (rate),
@@ -503,6 +508,7 @@ brasero_drive_properties_set_drive (BraseroDriveProperties *self,
 				    -1);
 		g_free (text);
 	}
+	g_free (rates);
 
 	/* Set active one preferably max speed */
 	gtk_tree_model_get_iter_first (model, &iter);
