@@ -55,8 +55,8 @@
 BRASERO_PLUGIN_BOILERPLATE (BraseroWodim, brasero_wodim, BRASERO_TYPE_PROCESS, BraseroProcess);
 
 struct _BraseroWodimPrivate {
-	gint64 current_track_end_pos;
-	gint64 current_track_written;
+	goffset current_track_end_pos;
+	goffset current_track_written;
 
 	gint current_track_num;
 	gint track_count;
@@ -128,7 +128,13 @@ brasero_wodim_stderr_read (BraseroProcess *process, const gchar *line)
 						BRASERO_BURN_ERROR_DRIVE_BUSY,
 						_("The drive is busy")));
 	}
-
+	else if (strstr (line, "Probably trying to use ultra high speed+ medium on improper writer")) {
+		/* Set a deferred error as this message tends to indicate a failure */
+		brasero_process_deferred_error (process,
+						g_error_new (BRASERO_BURN_ERROR,
+							     BRASERO_BURN_ERROR_MEDIUM_INVALID,
+							     _("The disc is not supported")));
+	}
 	/* REMINDER: these should not be necessary as we checked that already */
 	/**
 	else if (strstr (line, "cannot write medium - incompatible format") != NULL) {
@@ -196,30 +202,30 @@ brasero_wodim_stderr_read (BraseroProcess *process, const gchar *line)
 
 static void
 brasero_wodim_compute (BraseroWodim *wodim,
-		       gint mb_written,
-		       gint mb_total,
-		       gint track_num)
+		       goffset mb_written,
+		       goffset mb_total,
+		       goffset track_num)
 {
 	gboolean track_num_changed = FALSE;
 	BraseroWodimPrivate *priv;
 	BraseroJobAction action;
-	gint64 this_remain;
-	gint64 bytes;
-	gint64 total;
+	goffset this_remain;
+	goffset bytes;
+	goffset total;
 
 	priv = BRASERO_WODIM_PRIVATE (wodim);
 	if (mb_total <= 0)
 		return;
 
-	total = mb_total * 1048576;
+	total = mb_total * (goffset) 1048576LL;
 
 	if (track_num > priv->current_track_num) {
 		track_num_changed = TRUE;
 		priv->current_track_num = track_num;
-		priv->current_track_end_pos += mb_total * 1048576;
+		priv->current_track_end_pos += mb_total * (goffset) 1048576LL;
 	}
 
-	this_remain = (mb_total - mb_written) * 1048576;
+	this_remain = (mb_total - mb_written) * (goffset) 1048576LL;
 	bytes = (total - priv->current_track_end_pos) + this_remain;
 	brasero_job_set_written_session (BRASERO_JOB (wodim), total - bytes);
 
@@ -264,7 +270,7 @@ brasero_wodim_stdout_read (BraseroProcess *process, const gchar *line)
 			       (gdouble) CD_RATE;
 		brasero_job_set_rate (BRASERO_JOB (wodim), current_rate);
 
-		priv->current_track_written = mb_written * 1048576;
+		priv->current_track_written = (goffset) mb_written * (goffset) 1048576LL;
 		brasero_wodim_compute (wodim,
 				       mb_written,
 				       mb_total,
@@ -282,7 +288,7 @@ brasero_wodim_stdout_read (BraseroProcess *process, const gchar *line)
 			       (gdouble) CD_RATE;
 		brasero_job_set_rate (BRASERO_JOB (wodim), current_rate);
 
-		priv->current_track_written = mb_written * 1048576;
+		priv->current_track_written = (goffset) mb_written * (goffset) 1048576LL;
 		if (brasero_job_get_fd_in (BRASERO_JOB (wodim), NULL) == BRASERO_BURN_OK) {
 			gint64 bytes = 0;
 
@@ -290,7 +296,7 @@ brasero_wodim_stdout_read (BraseroProcess *process, const gchar *line)
 			brasero_job_get_session_output_size (BRASERO_JOB (wodim),
 							     NULL,
 							     &bytes);
-			mb_total = bytes / 1048576;
+			mb_total = bytes / (goffset) 1048576LL;
 			brasero_wodim_compute (wodim,
 					       mb_written,
 					       mb_total,
@@ -346,18 +352,31 @@ brasero_wodim_stdout_read (BraseroProcess *process, const gchar *line)
 	}
 	else if (g_str_has_prefix (line, "Fixating...")
 	     ||  g_str_has_prefix (line, "Writing Leadout...")) {
-		brasero_job_set_current_action (BRASERO_JOB (process),
-						BRASERO_BURN_ACTION_FIXATING,
-						NULL,
-						FALSE);
+		BraseroJobAction action;
+
+		/* Do this to avoid strange things to appear when erasing */
+		brasero_job_get_action (BRASERO_JOB (wodim), &action);
+		if (action == BRASERO_JOB_ACTION_RECORD)
+			brasero_job_set_current_action (BRASERO_JOB (process),
+							BRASERO_BURN_ACTION_FIXATING,
+							NULL,
+							FALSE);
 	}
 	else if (g_str_has_prefix (line, "Last chance to quit, ")) {
 		brasero_job_set_dangerous (BRASERO_JOB (process), TRUE);
 	}
-	else if (g_str_has_prefix (line, "Blanking PMA, TOC, pregap")
+/*	else if (g_str_has_prefix (line, "Blanking PMA, TOC, pregap")
 	     ||  strstr (line, "Blanking entire disk")) {
 
 	}
+ */
+	else if (strstr (line, "Disk sub type: Ultra High speed+")) {
+		/* Set a deferred error as this message tends to indicate a failure */
+		brasero_process_deferred_error (process,
+						g_error_new (BRASERO_BURN_ERROR,
+							     BRASERO_BURN_ERROR_MEDIUM_INVALID,
+							     _("The disc is not supported")));
+	}
 	/* This should not happen */
 	/* else if (strstr (line, "Use tsize= option in SAO mode to specify track size")) */
 
